@@ -1,6 +1,7 @@
-/* A Bison parser, made by GNU Bison 2.1a.  */
+/* A Bison parser, made by GNU Bison 2.2.  */
+
+/* Skeleton implementation for Bison LALR(1) parsers in C++
 
-/* C++ Skeleton parser for LALR(1) parsing with Bison,
    Copyright (C) 2002, 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -18,17 +19,30 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.  */
 
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
+
 
 #include "calc++-parser.hh"
 
 /* User implementation prologue.  */
-#line 7485 "../../doc/bison.texinfo"
+#line 7497 "../../doc/bison.texinfo"
 
 # include "calc++-driver.hh"
 
 
-/* Line 311 of lalr1.cc.  */
-#line 32 "./calc++-parser.cc"
+/* Line 317 of lalr1.cc.  */
+#line 46 "./calc++-parser.cc"
 
 #ifndef YY_
 # if YYENABLE_NLS
@@ -87,49 +101,49 @@ do {					\
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrorlab
 
+namespace yy
+{
 #if YYERROR_VERBOSE
 
-/* Return YYSTR after stripping away unnecessary quotes and
-   backslashes, so that it's suitable for yyerror.  The heuristic is
-   that double-quoting is unnecessary unless the string contains an
-   apostrophe, a comma, or backslash (other than backslash-backslash).
-   YYSTR is taken from yytname.  */
-std::string
-yy::calcxx_parser::yytnamerr_ (const char *yystr)
-{
-  if (*yystr == '"')
-    {
-      std::string yyr = "";
-      char const *yyp = yystr;
+  /* Return YYSTR after stripping away unnecessary quotes and
+     backslashes, so that it's suitable for yyerror.  The heuristic is
+     that double-quoting is unnecessary unless the string contains an
+     apostrophe, a comma, or backslash (other than backslash-backslash).
+     YYSTR is taken from yytname.  */
+  std::string
+  calcxx_parser::yytnamerr_ (const char *yystr)
+  {
+    if (*yystr == '"')
+      {
+        std::string yyr = "";
+        char const *yyp = yystr;
 
-      for (;;)
-	switch (*++yyp)
-	  {
-	  case '\'':
-	  case ',':
-	    goto do_not_strip_quotes;
+        for (;;)
+          switch (*++yyp)
+            {
+            case '\'':
+            case ',':
+              goto do_not_strip_quotes;
 
-	  case '\\':
-	    if (*++yyp != '\\')
-	      goto do_not_strip_quotes;
-	    /* Fall through.  */
-	  default:
-	    yyr += *yyp;
-	    break;
+            case '\\':
+              if (*++yyp != '\\')
+                goto do_not_strip_quotes;
+              /* Fall through.  */
+            default:
+              yyr += *yyp;
+              break;
 
-	  case '"':
-	    return yyr;
-	  }
-    do_not_strip_quotes: ;
-    }
+            case '"':
+              return yyr;
+            }
+      do_not_strip_quotes: ;
+      }
 
-  return yystr;
-}
+    return yystr;
+  }
 
 #endif
 
-namespace yy
-{
   /// Build a parser object.
   calcxx_parser::calcxx_parser (calcxx_driver& driver_yyarg)
     : yydebug_ (false),
@@ -156,19 +170,19 @@ namespace yy
     switch (yytype)
       {
         case 4: /* "\"identifier\"" */
-#line 7514 "../../doc/bison.texinfo"
+#line 7526 "../../doc/bison.texinfo"
 	{ debug_stream () << *(yyvaluep->sval); };
-#line 162 "./calc++-parser.cc"
+#line 176 "./calc++-parser.cc"
 	break;
       case 5: /* "\"number\"" */
-#line 7517 "../../doc/bison.texinfo"
+#line 7529 "../../doc/bison.texinfo"
 	{ debug_stream () << (yyvaluep->ival); };
-#line 167 "./calc++-parser.cc"
+#line 181 "./calc++-parser.cc"
 	break;
       case 6: /* "\"expression\"" */
-#line 7517 "../../doc/bison.texinfo"
+#line 7529 "../../doc/bison.texinfo"
 	{ debug_stream () << (yyvaluep->ival); };
-#line 172 "./calc++-parser.cc"
+#line 186 "./calc++-parser.cc"
 	break;
        default:
 	  break;
@@ -201,9 +215,9 @@ namespace yy
     switch (yytype)
       {
         case 4: /* "\"identifier\"" */
-#line 7515 "../../doc/bison.texinfo"
+#line 7527 "../../doc/bison.texinfo"
 	{ delete (yyvaluep->sval); };
-#line 207 "./calc++-parser.cc"
+#line 221 "./calc++-parser.cc"
 	break;
 
 	default:
@@ -279,13 +293,13 @@ namespace yy
 
 
     /* User initialization code.  */
-    #line 7448 "../../doc/bison.texinfo"
+    #line 7460 "../../doc/bison.texinfo"
 {
   // Initialize the initial location.
   yylloc.begin.filename = yylloc.end.filename = &driver.file;
 }
-  /* Line 549 of yacc.c.  */
-#line 289 "./calc++-parser.cc"
+  /* Line 555 of yacc.c.  */
+#line 303 "./calc++-parser.cc"
     /* Initialize the stacks.  The initial state will be pushed in
        yynewstate, since the latter expects the semantical and the
        location values to have been already stored, initialize these
@@ -401,58 +415,58 @@ namespace yy
     switch (yyn)
       {
 	  case 2:
-#line 7527 "../../doc/bison.texinfo"
+#line 7539 "../../doc/bison.texinfo"
     { driver.result = (yysemantic_stack_[(2) - (2)].ival); ;}
     break;
 
   case 3:
-#line 7529 "../../doc/bison.texinfo"
+#line 7541 "../../doc/bison.texinfo"
     {;}
     break;
 
   case 4:
-#line 7530 "../../doc/bison.texinfo"
+#line 7542 "../../doc/bison.texinfo"
     {;}
     break;
 
   case 5:
-#line 7532 "../../doc/bison.texinfo"
+#line 7544 "../../doc/bison.texinfo"
     { driver.variables[*(yysemantic_stack_[(3) - (1)].sval)] = (yysemantic_stack_[(3) - (3)].ival); ;}
     break;
 
   case 6:
-#line 7536 "../../doc/bison.texinfo"
+#line 7548 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) + (yysemantic_stack_[(3) - (3)].ival); ;}
     break;
 
   case 7:
-#line 7537 "../../doc/bison.texinfo"
+#line 7549 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) - (yysemantic_stack_[(3) - (3)].ival); ;}
     break;
 
   case 8:
-#line 7538 "../../doc/bison.texinfo"
+#line 7550 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) * (yysemantic_stack_[(3) - (3)].ival); ;}
     break;
 
   case 9:
-#line 7539 "../../doc/bison.texinfo"
+#line 7551 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) / (yysemantic_stack_[(3) - (3)].ival); ;}
     break;
 
   case 10:
-#line 7540 "../../doc/bison.texinfo"
+#line 7552 "../../doc/bison.texinfo"
     { (yyval.ival) = driver.variables[*(yysemantic_stack_[(1) - (1)].sval)]; ;}
     break;
 
   case 11:
-#line 7541 "../../doc/bison.texinfo"
+#line 7553 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(1) - (1)].ival); ;}
     break;
 
 
-    /* Line 669 of lalr1.cc.  */
-#line 456 "./calc++-parser.cc"
+    /* Line 675 of lalr1.cc.  */
+#line 470 "./calc++-parser.cc"
 	default: break;
       }
     YY_SYMBOL_PRINT ("-> $$ =", yyr1_[yyn], &yyval, &yyloc);
@@ -615,14 +629,14 @@ namespace yy
     YYUSE (yystate);
 #if YYERROR_VERBOSE
     int yyn = yypact_[yystate];
-    if (yypact_ninf_ < yyn && yyn < yylast_)
+    if (yypact_ninf_ < yyn && yyn <= yylast_)
       {
 	/* Start YYX at -YYN if negative to avoid negative indexes in
 	   YYCHECK.  */
 	int yyxbegin = yyn < 0 ? -yyn : 0;
 
 	/* Stay within bounds of both yycheck and yytname.  */
-	int yychecklim = yylast_ - yyn;
+	int yychecklim = yylast_ - yyn + 1;
 	int yyxend = yychecklim < yyntokens_ ? yychecklim : yyntokens_;
 	int count = 0;
 	for (int x = yyxbegin; x < yyxend; ++x)
@@ -782,8 +796,8 @@ namespace yy
   const unsigned short int
   calcxx_parser::yyrline_[] =
   {
-         0,  7527,  7527,  7529,  7530,  7532,  7536,  7537,  7538,  7539,
-    7540,  7541
+         0,  7539,  7539,  7541,  7542,  7544,  7548,  7549,  7550,  7551,
+    7552,  7553
   };
 
   // Print the state stack on the debug stream.
@@ -817,7 +831,7 @@ namespace yy
 
   /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
   calcxx_parser::token_number_type
-  calcxx_parser::yytranslate_ (int token)
+  calcxx_parser::yytranslate_ (int t)
   {
     static
     const token_number_type
@@ -851,8 +865,8 @@ namespace yy
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
        5,     6
     };
-    if ((unsigned int) token <= yyuser_token_number_max_)
-      return translate_table[token];
+    if ((unsigned int) t <= yyuser_token_number_max_)
+      return translate_table[t];
     else
       return yyundef_token_;
   }
@@ -871,9 +885,9 @@ namespace yy
 
 } // namespace yy
 
-#line 7542 "../../doc/bison.texinfo"
+#line 7554 "../../doc/bison.texinfo"
 
-#line 7551 "../../doc/bison.texinfo"
+#line 7563 "../../doc/bison.texinfo"
 void
 yy::calcxx_parser::error (const yy::calcxx_parser::location_type& l,
                           const std::string& m)
